Brightway2-analyzer
*******************

Contribution analysis
=====================

.. autoclass:: bw2analyzer.ContributionAnalysis
    :members:

Supply chain traversal
======================

.. autofunction:: bw2analyzer.traverse_tagged_databases

This function uses the following help functions:

.. autofunction:: bw2analyzer.tagged.aggregate_tagged_graph

.. autofunction:: bw2analyzer.tagged.recurse_tagged_database

LCA reports
===========

.. autoclass:: bw2analyzer.SerializedLCAReport
    :members:

PageRank algorithm
==================

.. autoclass:: bw2analyzer.PageRank
    :members:
